USE SAKILA;

#LEFT JOIN 2 TABLES
SELECT C.CUSTOMER_ID,C.FIRST_NAME,C.LAST_NAME
FROM CUSTOMER C
LEFT JOIN ACTOR A 
ON C.LAST_NAME = A.LAST_NAME
WHERE A.LAST_NAME IS NULL
ORDER BY C.LAST_NAME DESC;

#LEFT JOIN WITH USING
SELECT C.CUSTOMER_ID,C.FIRST_NAME,C.LAST_NAME
FROM CUSTOMER C
LEFT JOIN ACTOR A 
USING (LAST_NAME)
WHERE A.LAST_NAME IS NULL
ORDER BY C.LAST_NAME DESC;


#LEFT JOIN COMBINED WITH OTHER JOINS
SELECT ADR.ADDRESS,ADR.DISTRICT,CT.CITY, CN.COUNTRY,ADR.POSTAL_CODE
FROM ADDRESS ADR 
LEFT JOIN STORE ST
ON ST.ADDRESS_ID = ADR.ADDRESS_ID
JOIN CITY CT USING (CITY_ID)
JOIN COUNTRY CN USING (COUNTRY_ID)
WHERE ST.ADDRESS_ID IS NULL;

#LEFT JOIN MULTIPLE TABLES
SELECT COUNT(F.RATING),F.RATING,SUM( IFNULL(PAY.AMOUNT, 0) ) REVENUE
FROM FILM_CATEGORY FC
LEFT JOIN CATEGORY CAT
ON CAT.CATEGORY_ID = FC.CATEGORY_ID
LEFT JOIN FILM F
ON FC.FILM_ID = F.FILM_ID
LEFT JOIN INVENTORY INV
ON F.FILM_ID = INV.FILM_ID
LEFT JOIN RENTAL REN
ON INV.INVENTORY_ID = REN.INVENTORY_ID
LEFT JOIN PAYMENT PAY
ON REN.RENTAL_ID = PAY.RENTAL_ID
WHERE FC.CATEGORY_ID IS NULL
GROUP BY F.RATING;

#SIMPLE NOT IN
SELECT *
FROM FILM
WHERE LANGUAGE_ID NOT IN (
	SELECT LANGUAGE_ID 
	FROM LANGUAGE 
	WHERE NAME = 'ENGLISH'
)
ORDER BY TITLE;

#NOT IN MULTIPLE TIMES ON SAME COLUMNS, COMBINED WITH OTHER OPERANDS.
SELECT FILM_ID,TITLE,DESCRIPTION,RATING,SPECIAL_FEATURES 
FROM FILM
WHERE FILM_ID NOT IN(
SELECT FILM_ID
FROM FILM JOIN FILM_CATEGORY USING (FILM_ID) JOIN CATEGORY USING (CATEGORY_ID)
GROUP BY CATEGORY.NAME
HAVING AVG(LENGTH) < (SELECT AVG(LENGTH) FROM FILM))
AND FILM_ID NOT IN(
SELECT FILM_ID FROM INVENTORY
WHERE INVENTORY_ID IN (SELECT INVENTORY_ID FROM RENTAL WHERE INVENTORY_ID IS NULL));

#Simple NOT EXISTS
SELECT * FROM INVENTORY WHERE
NOT EXISTS (
 SELECT 1 FROM RENTAL WHERE RENTAL.INVENTORY_ID=10
 AND RETURN_DATE IS NULL
);

#NOT EXISTS WITH OTHER CONDITIONS
SELECT INVENTORY_ID,RENTAL_DATE,RETURN_DATE,STAFF_ID
FROM INVENTORY JOIN STORE USING (STORE_ID)
     JOIN FILM USING (FILM_ID)
     JOIN RENTAL USING (INVENTORY_ID)
WHERE FILM.TITLE = 'ACADEMY DINOSAUR'
      AND STORE.STORE_ID = 1
      AND NOT EXISTS (SELECT * FROM RENTAL
                      WHERE RENTAL.INVENTORY_ID = INVENTORY.INVENTORY_ID
                      AND RENTAL.RETURN_DATE IS NULL);


